<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Chat;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class ChatController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware('permission:Chat List', ['only' => ['index']]);
        $this->middleware('permission:Create Chat', ['only' => ['create', 'store']]);
        $this->middleware('permission:Edit Chat', ['only' => ['edit', 'update']]);
        $this->middleware('permission:Delete Chat', ['only' => ['destroy']]);
    }
    public function index(Request $request)
    {
        $chats = Chat::all();
        return view('admin.chat.index', compact('chats'));
    }
    public function psychic_index()
    {
        if (Auth::user()->hasRole('Psychic')) {
        $chats = Chat::where('psychic_id', Auth::user()->id)
            ->with(['user', 'psychic']) // Eager load relationships
            ->orderBy('created_at', 'desc')
            ->get() // Fetch all records
            ->groupBy('user_id') // Group by user_id
            ->map(function ($group) {
                return [
                    'user_id' => $group->first()->user_id, // Get the user_id
                    'messages' => $group->sortBy('created_at')->toArray() // Include all columns in the messages array
                ];
            })
            ->values();
        return view('psychic.chat.index', compact('chats'));
        }
        else{
            return redirect('/dashboard');
        }
    }
    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.chat.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'minute' => 'required',
            'price' => 'required',
            'description' => 'nullable'
        ]);
        $chat = Chat::create($validatedData);
        $message = 'Chat Created Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Chat $chat)
    {
        return view('admin.chat.edit', compact('chat'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Chat $chat)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'minute' => 'required',
            'price' => 'required',
            'description' => 'nullable'
        ]);
        $chat = $chat->update($validatedData);
        // Optionally, you can redirect to a success page or perform other actions
        $message = 'Chat Updated Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Chat $chat)
    {
        $chat->delete();
        $message = 'Chat Deleted successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }
}
