<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Package;
use Illuminate\Http\Request;

class PackageController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware('permission:Package List', ['only' => ['index']]);
        $this->middleware('permission:Create Package', ['only' => ['create', 'store']]);
        $this->middleware('permission:Edit Package', ['only' => ['edit', 'update']]);
        $this->middleware('permission:Delete Package', ['only' => ['destroy']]);
    }
    public function index(Request $request)
    {
        $packages = Package::all();
        return view('admin.package.index', compact('packages'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.package.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'minute' => 'required',
            'price' => 'required',
            'description' => 'nullable'
        ]);
        $package = Package::create($validatedData);
        $message = 'Package Created Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Package $package)
    {
        return view('admin.package.edit', compact('package'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Package $package)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'minute' => 'required',
            'price' => 'required',
            'description' => 'nullable'
        ]);
        $package = $package->update($validatedData);
        // Optionally, you can redirect to a success page or perform other actions
        $message = 'Package Updated Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Package $package)
    {
        $package->delete();
        $message = 'Package Deleted successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }
}
