<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\PerMinutePackage;
use Illuminate\Http\Request;

class PerMinutePackageController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware('permission:PerMinutePackage List', ['only' => ['index']]);
        $this->middleware('permission:Create PerMinutePackage', ['only' => ['create', 'store']]);
        $this->middleware('permission:Edit PerMinutePackage', ['only' => ['edit', 'update']]);
        $this->middleware('permission:Delete PerMinutePackage', ['only' => ['destroy']]);
    }
    public function index(Request $request)
    {
        $per_minute_packages = PerMinutePackage::all();
        return view('admin.per_minute_package.index', compact('per_minute_packages'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.per_minute_package.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'price' => 'required',
            'type' => 'required',
            'description' => 'nullable'
        ]);
        $per_minute_package = PerMinutePackage::create($validatedData);
        $message = 'Per Minute Package Created Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(PerMinutePackage $per_minute_package)
    {
        return view('admin.per_minute_package.edit', compact('per_minute_package'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, PerMinutePackage $per_minute_package)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'price' => 'required',
            'type' => 'required',
            'description' => 'nullable'
        ]);
        $per_minute_package = $per_minute_package->update($validatedData);
        // Optionally, you can redirect to a success page or perform other actions
        $message = 'Per Minute Package Updated Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(PerMinutePackage $per_minute_package)
    {
        $per_minute_package->delete();
        $message = 'Per Minute Package Deleted successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }
}
