<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\PsychicCategory;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;

class PsychicCategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware('permission:PsychicCategory List', ['only' => ['index']]);
        $this->middleware('permission:Create PsychicCategory', ['only' => ['create', 'store']]);
        $this->middleware('permission:Edit PsychicCategory', ['only' => ['edit', 'update']]);
        $this->middleware('permission:Delete PsychicCategory', ['only' => ['destroy']]);
    }
    public function index(Request $request)
    {
        $psychic_categories = PsychicCategory::all();
        return view('admin.psychic_category.index', compact('psychic_categories'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.psychic_category.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'name' => ['required', 'string', 'max:255', 'unique:' . PsychicCategory::class],
            'icon' => 'required',
            'description' => 'required',
        ]);
        $psychic_category = PsychicCategory::create($validatedData);
        $message = 'Psychic Category Created Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);

    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(PsychicCategory $psychic_category)
    {
        return view('admin.psychic_category.edit', compact('psychic_category'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, PsychicCategory $psychic_category)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'name' => ['required', 'string', 'max:255', Rule::unique('psychic_categories')->ignore($psychic_category->id)],
            'icon' => 'required',
            'description' => 'required',
        ]);
        $psychic_category = $psychic_category->update($validatedData);
        // Optionally, you can redirect to a success page or perform other actions
        $message = 'Psychic Category Updated Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(PsychicCategory $psychic_category)
    {
        $psychic_category->delete();
        $message = 'Psychic Category Deleted Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);

    }
}
