<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Review;
use App\Models\User;
use Illuminate\Http\Request;

class ReviewController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {
        $this->middleware('permission:Review List', ['only' => ['index']]);
        $this->middleware('permission:Create Review', ['only' => ['create', 'store']]);
        $this->middleware('permission:Edit Review', ['only' => ['edit', 'update']]);
        $this->middleware('permission:Delete Review', ['only' => ['destroy']]);
    }
    public function index(Request $request)
    {
        $reviews = Review::with(['user', 'psychic'])->get();
        return view('admin.review.index', compact('reviews'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $users = User::all();
        return view('admin.review.create', compact('users'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        // Validate the incoming request data
        $validatedData = $request->validate(
            [
                'rating' => 'required',
                'comment' => 'nullable',
                'user_id' => 'required',
                'psychic_id' => 'required'
            ],
            [
                'user_id.required' => 'The user field is required.',
                'psychic_id.required' => 'The psychic field is required.', 
            ]
        );
        $review = Review::create($validatedData);
        $message = 'Review Created Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Review $review)
    {
        $review->load(['user', 'psychic']);
        $users = User::all();
        return view('admin.review.edit', compact('review', 'users'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Review $review)
    {
        // Validate the incoming request data
        $validatedData = $request->validate([
            'rating' => 'required',
            'comment' => 'nullable',
            'user_id' => 'required',
            'psychic_id' => 'required'
        ],
        [
            'user_id.required' => 'The user field is required.',
            'psychic_id.required' => 'The psychic field is required.', 
        ]);
        $review = $review->update($validatedData);
        // Optionally, you can redirect to a success page or perform other actions
        $message = 'Review Updated Successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Review $review)
    {
        $review->delete();
        $message = 'Review Deleted successfully';
        $type = 'success';
        return redirect()->back()->with('message', $message)->with('type', $type);
    }
}
