<?php

namespace App\Http\Controllers\Frontend;

use App\Models\PerMinutePackage;
use App\Models\PsychicCategory;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\User;

class FrontendPsychicCategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {

    }
    /**
     * Show the form for editing the specified resource.
     */
    public function index($psychic_category_name, Request $request)
    {
        $psychic_category = PsychicCategory::where('name', $psychic_category_name)->first();
        $users = User::role('Psychic')
            ->whereHas('psychic_info', function ($query) use ($psychic_category, $request) {
                $query->where('per_minute_package_chat_id', '!=', '')
                    ->where('per_minute_package_voice_id', '!=', '')
                    ->whereJsonContains('psychic_category_id', (string) $psychic_category->id);
                if ($request->query('chat')) {
                    $query->where($request->query('chat'), '=', 1);
                }
                if ($request->query('offline')) {
                    $query->where('online_status', '!=', 'Offline');
                }
            })
            ->where('approved', 1)
            ->withCount(['booking', 'review'])
            ->having('review_count', '>=', $request->query('reviews', 0))
            ->whereHas(
                'psychic_info.per_minute_package_chat',
                function ($query) use ($request) {
                    if ($request->query('min_price')) {
                        $query->whereBetween('price', [$request->query('min_price'), $request->query('max_price')]);
                    }
                }
            )
            ->whereHas(
                'psychic_info.per_minute_package_voice',
                function ($query) use ($request) {
                    if ($request->query('min_price')) {
                        $query->whereBetween('price', [$request->query('min_price'), $request->query('max_price')]);
                    }
                }
            )
            ->withAvg('review', 'rating')
            ->get();
        $start_price = PerMinutePackage::min('price');
        $end_price = PerMinutePackage::max('price');
        $class_name = 'single-psychic';
        return view('frontend.psychic-category', compact('users', 'psychic_category', 'class_name', 'start_price', 'end_price', 'request'));
    }
    public function all_advisors(Request $request)
    {
        $search_term = $request->query('s');
        $users = User::role('Psychic')
            ->where(function ($query) use ($search_term) {
                $query->where('fname', 'like', '%' . $search_term . '%')
                    ->orWhere('lname', 'like', '%' . $search_term . '%')
                    ->orWhere('name', 'like', '%' . $search_term . '%');
            })->whereHas('psychic_info', function ($query) use ($request) {
                $query->where('per_minute_package_chat_id', '!=', '')
                    ->where('per_minute_package_voice_id', '!=', '');
                if ($request->query('chat')) {
                    $query->where($request->query('chat'), '=', 1);
                }
                if ($request->query('offline')) {
                    $query->where('online_status', '!=', 'Offline');
                }
            })
            ->where('approved', 1)
            ->withCount(['booking', 'review'])
            ->having('review_count', '>=', $request->query('reviews', 0))
            ->whereHas(
                'psychic_info.per_minute_package_chat',
                function ($query) use ($request) {
                    if ($request->query('min_price')) {
                        $query->whereBetween('price', [$request->query('min_price'), $request->query('max_price')]);
                    }
                }
            )
            ->whereHas(
                'psychic_info.per_minute_package_voice',
                function ($query) use ($request) {
                    if ($request->query('min_price')) {
                        $query->whereBetween('price', [$request->query('min_price'), $request->query('max_price')]);
                    }
                }
            )
            ->withAvg('review', 'rating')
            ->get();
        $start_price = PerMinutePackage::min('price');
        $end_price = PerMinutePackage::max('price');
        $class_name = 'single-psychic';
        return view('frontend.all-advisors', compact('users', 'class_name', 'start_price', 'end_price', 'request'));
    }
}
