<?php

namespace App\Http\Controllers\Frontend;

use App\Http\Controllers\Controller;
use App\Models\Booking;
use App\Models\Chat;
use App\Events\MessageSent;
use App\Models\Package;
use App\Models\PsychicInfo;
use App\Models\Review;
use App\Models\User;
use App\Models\UserInfo;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Stripe\Stripe;
use Stripe\Charge;
use Illuminate\Support\Str;
use Twilio\Jwt\ClientToken;

class SinglePsychicController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function __construct()
    {

    }
    /**
     * Show the form for editing the specified resource.
     */
    public function index($name)
    {
        $user = User::role('Psychic')
            ->with([
                'psychic_info.per_minute_package_chat',
                'psychic_info.per_minute_package_voice',
                'review' => function ($query) {
                    $query->whereNotNull('comment')->with('user')->limit(20);
                }
            ])->withAvg('review', 'rating')->withCount([
                    'booking',
                    'review' => function ($query) {
                        $query->whereNotNull('comment');
                    }
                ])->where('name', $name)->first();
        $packages = Package::all();
        $class_name = 'single-psychic';
        return view('frontend.single-psychic', compact('user', 'packages', 'class_name'));
    }
    public function more_review(Request $request)
    {
        $reviews = Review::whereNotNull('comment')->with('user')->offset($request->offset)->limit(20)->where('psychic_id', $request->id)->get();
        $review_count = Review::whereNotNull('comment')->where('psychic_id', $request->id)->count();
        $request->offset += 20;
        $review_count -= $request->offset;
        $html = '';
        foreach ($reviews as $review) {
            $html .=
                '<div class="review-list">
                <div>
                    <h2>' . $review->user->name . '</h2>
                    <p class="p-0">' . $review->comment . '</p>
                </div>
                <span>' . date('d M Y', strtotime($review->created_at)) . '</span>
            </div>';
        }
        return response()->json([
            'success' => 'success',
            'review_count' => $review_count,
            'offset' => $request->offset,
            'html' => $html
        ]);
    }
    public function rating(Request $request)
    {
        $review = Review::create([
            'rating' => $request->rating,
            'comment' => $request->comment,
            'user_id' => Auth::user()->id,
            'psychic_id' => $request->psychic_id
        ]);
        return response()->json([
            'success' => 'success'
        ]);
    }
    public function fav_psychic(Request $request)
    {
        $user = Auth::user();
        $is_added = 1;
        $user_info = UserInfo::where('user_id', $user->id)->first();
        $fav_psychic = $user_info->fav_psychic ?? [];
        if (in_array($request->id, $fav_psychic)) {
            $fav_psychic = array_diff($fav_psychic, [$request->id]);
            $is_added = 0;
        } else {
            $fav_psychic[] = $request->id;
        }
        $updated_user_info = $user_info->update([
            'fav_psychic' => $fav_psychic,
        ]);
        return response()->json([
            'success' => $is_added
        ]);
    }
    public function psychic_voice_call(Request $request)
    {
        $psychic_info = PsychicInfo::where('user_id', $request->id)->first();
        if ($request->call == 'start') {
            if ($psychic_info->online_status == 'Online') {
                $updated_psychic_info = $psychic_info->update([
                    'online_status' => 'Busy',
                ]);
                $success = 'yes';
                $message = '';
            } else {
                $message = 'Sorry Psychic Has Immediately Become ' . $psychic_info->online_status;
                $success = 'no';
            }
        } else {
            $user = Auth::user();
            $user_info = UserInfo::where('user_id', $user->id)->first();
            $updated_user_info = $user_info->update([
                'balance' => $request->balance,
            ]);
            $updated_psychic_info = $psychic_info->update([
                'online_status' => 'Online',
            ]);
            $booking = Booking::create([
                'minute' => $request->minute,
                'cost' => $request->cost,
                'psychic_id' => $request->id,
                'user_id' => $user->id,
            ]);
            $success = 'yes';
            $message = '';
        }
        return response()->json([
            'message' => $message,
            'success' => $success
        ]);
    }
    public function voice_call($name)
    {
        if (!Auth::user()->hasRole('Super Admin') && !Auth::user()->hasRole('Psychic')) {
            $user = User::role('Psychic')->with(['psychic_info.per_minute_package_voice'])->where('name', $name)->first();
            $logged_in_user = Auth::user();
            $logged_in_user_info = $logged_in_user->load('user_info');
            if (($logged_in_user_info->user_info->balance >= $user->psychic_info->per_minute_package_voice->price) && ($user->psychic_info->online_status == 'Online')) {
                $class_name = 'voice-call';
                return view('frontend.voice-call', compact('user', 'logged_in_user_info', 'class_name'));
            } else {
                return redirect('/');
            }
        } else {
            return redirect('/');
        }
    }
    public function twilio_token()
    {
        // Twilio Account SID and Auth Token
        $account_sid = 'ACf4a19d3132b761b06572cec63c8829f8';
        $auth_token = '724129b0c54035005812927ff927fa41';

        // Twilio Application SID (Twiml App SID)
        $app_sid = 'APf5d21b8087b4a816cecd4c3513ac81e5';

        // Client identity (you can use this to identify the user)
        $client_identity = 'ACf4a19d3132b761b06572cec63c8829f8'; // Replace with your client's identity

        // Create a new capability token
        $capability = new ClientToken($account_sid, $auth_token);

        // Allow the client to make outgoing calls using the Twilio App SID
        $capability->allowClientOutgoing($app_sid);

        // Optionally, allow the client to receive incoming calls
        $capability->allowClientIncoming($client_identity);

        // Generate the capability token
        $token = $capability->generateToken();

        // Output the token as a JSON response
        header('Content-Type: application/json');
        echo json_encode(['token' => $token]);
    }
    public function twilio_request()
    {
        return view('twilio.request');
    }
    public function chat($name)
    {
        if (!Auth::user()->hasRole('Super Admin') && !Auth::user()->hasRole('Psychic')) {
            $psychic = User::role('Psychic')->where('name', $name)->with(['psychic_info.per_minute_package_chat'])->first();
            $psychic_info = PsychicInfo::where('user_id', $psychic->id)->first();
            $logged_in_user = Auth::user();
            $logged_in_user_info = $logged_in_user->load('user_info');
            $user_info = UserInfo::where('user_id', $logged_in_user->id)->first();
            $updated_user_info = $user_info->update([
                'balance' => $logged_in_user_info->user_info->balance - $psychic->psychic_info->per_minute_package_chat->price < 0 ? 0 : $logged_in_user_info->user_info->balance - $psychic->psychic_info->per_minute_package_chat->price,
            ]);
            if ($logged_in_user_info->user_info->balance >= $psychic->psychic_info->per_minute_package_chat->price) {
                if ($psychic_info->online_status == 'Online') {
                    $updated_psychic_info = $psychic_info->update([
                        'online_status' => 'Busy',
                    ]);
                    $booking = Booking::create([
                        'minute' => 0,
                        'cost' => $psychic->psychic_info->per_minute_package_chat->price,
                        'psychic_id' => $psychic->id,
                        'user_id' => $logged_in_user->id,
                    ]);
                    $psychicId = $psychic->id;
                    $userId = $logged_in_user->id;
                    $bookingId = $booking->id;
                    $cost = $psychic->psychic_info->per_minute_package_chat->price;
                    $balance = $logged_in_user_info->user_info->balance - $psychic->psychic_info->per_minute_package_chat->price;
                    $userName = $psychic->name;
                    $name = $psychic->fname . ' ' . $psychic->lname;
                    $profileImage = $psychic->image ? asset('images/' . $psychic->image) : asset('assets/images/user.png');
                    $class_name = 'single-psychic';
                    return view('frontend.chat', compact(
                        'psychicId',
                        'userId',
                        'bookingId',
                        'cost',
                        'balance',
                        'userName',
                        'name',
                        'profileImage',
                        'class_name'
                    ));
                } else {
                    return redirect('/');
                }
            } else {
                return redirect('/');
            }
        } else {
            return redirect('/');
        }
    }
    // public function chat(Request $request)
    // {
    //     if (!Auth::user()->hasRole('Super Admin') && !Auth::user()->hasRole('Psychic')) {
    //         $psychic = User::role('Psychic')->with(['psychic_info.per_minute_package_chat'])->find($request->id);
    //         $psychic_info = PsychicInfo::where('user_id', $request->id)->first();
    //         $logged_in_user = Auth::user();
    //         $logged_in_user_info = $logged_in_user->load('user_info');
    //         $user_info = UserInfo::where('user_id', $logged_in_user->id)->first();
    //         $updated_user_info = $user_info->update([
    //             'balance' => $logged_in_user_info->user_info->balance - $psychic->psychic_info->per_minute_package_chat->price,
    //         ]);
    //         if ($logged_in_user_info->user_info->balance >= $psychic->psychic_info->per_minute_package_chat->price) {
    //             if ($psychic_info->online_status == 'Online') {
    //                 $updated_psychic_info = $psychic_info->update([
    //                     'online_status' => 'Busy',
    //                 ]);
    //                 $booking = Booking::create([
    //                     'minute' => 0,
    //                     'cost' => $psychic->psychic_info->per_minute_package_chat->price,
    //                     'psychic_id' => $psychic->id,
    //                     'user_id' => $logged_in_user->id,
    //                 ]);
    //                 return response()->json([
    //                     'psychicId' => $psychic->id,
    //                     'userId' => $logged_in_user->id,
    //                     'bookingId' => $booking->id,
    //                     'cost' => $psychic->psychic_info->per_minute_package_chat->price,
    //                     'balance' => $logged_in_user_info->user_info->balance - $psychic->psychic_info->per_minute_package_chat->price,
    //                     'userName' => $psychic->name,
    //                     'name' => $psychic->fname . ' ' . $psychic->lname,
    //                     'profileImage' => $psychic->image ? asset('images/' . $psychic->image) : asset('assets/images/user.png'),
    //                     'success' => 'yes'
    //                 ]);
    //             } else {
    //                 return response()->json([
    //                     'message' => 'Sorry Psychic Has Immediately Become ' . $psychic_info->online_status,
    //                     'success' => 'no'
    //                 ]);
    //             }
    //         } else {
    //             return response()->json([
    //                 'message' => 'You Have Not Enough Balance',
    //                 'success' => 'no'
    //             ]);
    //         }
    //     } else {
    //         return response()->json([
    //             'message' => 'You are not customer',
    //             'success' => 'no'
    //         ]);
    //     }
    // }
    public function current_chatdate(Request $request)
    {
        $chat = Chat::find($request->chat_id);
        if (in_array('Psychic', $request->user)) {
            $chat = $chat->update([
                'psychic_time' => $request->date
            ]);
        } else {
            $chat = $chat->update([
                'user_time' => $request->date
            ]);
        }
    }
    public function end_chat(Request $request)
    {
        $user = Auth::user();
        $user_info = UserInfo::where('user_id', $user->id)->first();
        $updated_user_info = $user_info->update([
            'balance' => $request->balance,
        ]);
        $psychic_info = PsychicInfo::where('user_id', $request->psychic_id)->first();
        $updated_psychic_info = $psychic_info->update([
            'online_status' => 'Online',
        ]);
        $booking = Booking::find($request->booking_id);
        $booking = $booking->update([
            'minute' => $request->minute,
            'cost' => $request->cost,
            'psychic_id' => $request->psychic_id,
            'user_id' => $request->user_id,
        ]);
        broadcast(new MessageSent($request->psychic_id, []))->toOthers();
    }
    public function send_message(Request $request)
    {
        $user = Auth::user();
        $user_time = $psychic_time = 0;
        $booking_id = '';
        if ($user->hasRole('Psychic')) {
            $psychic_time = $request->time;
            $user_time = 0;
            if (!$request->booking_id) {
                $booking = Booking::create([
                    'minute' => 0,
                    'cost' => 0,
                    'psychic_id' => $request->psychic_id,
                    'user_id' => $request->user_id,
                ]);
                $booking_id = $booking->id;
            } else {
                $booking_id = $request->booking_id;
            }
        } else {
            if ($request->booking_id != null) {
                $booking = Booking::create([
                    'minute' => 0,
                    'cost' => 0,
                    'psychic_id' => $request->psychic_id,
                    'user_id' => $request->user_id,
                ]);
                $booking_id = $booking->id;
            } else {
                $booking_id = $request->booking_id;
            }
            $psychic_time = 0;
            $user_time = $request->time;
            if (!$request->booking_id) {
                $user_info = UserInfo::where('user_id', $user->id)->first();
                $updated_user_info = $user_info->update([
                    'balance' => $request->balance,
                ]);

                $booking = Booking::find($booking_id);
                $booking = $booking->update([
                    'minute' => $request->minute,
                    'cost' => $request->cost,
                    'psychic_id' => $request->psychic_id,
                    'user_id' => $request->user_id,
                ]);
            }
        }
        $chat = Chat::create([
            'message' => $request->message,
            'user_time' => $user_time,
            'psychic_time' => $psychic_time,
            'booking_id' => $booking_id,
            'receiver_id' => $request->receiver_id,
            'psychic_id' => $request->psychic_id,
            'user_id' => $request->user_id,
        ]);
        $chat->load(['user', 'psychic']);
        broadcast(new MessageSent($request->receiver_id, $chat))->toOthers();
    }
    public function payment(Request $request)
    {
        $success = '';
        $user = Auth::user();
        \Stripe\Stripe::setApiKey('sk_test_51LkKtsFRGZchVnkCZ9FL8r76fy9GKFWkmNwVHYwXGKgLJ7YSbQrlQQB4djUMmEarIV9zwoiAEdcf0fC1Z8YvmcYC00xbzq2vm9');
        try {
            $customer = \Stripe\Customer::create(
                array(
                    "email" => $user->email,
                    "source" => $request->token // or other payment source token
                )
            );
        } catch (Exception $e) {
            /*
             * if something went wrong
             */
            $message = $e->getMessage();
            return response()->json([
                'message' => $message,
                'success' => $success
            ]);
        }
        try {
            $charge = Charge::create([
                'amount' => $request->price * 100, // Amount in cents
                'currency' => 'usd',
                'customer' => $customer->id, // Customer ID
                'description' => '',
            ]);
            $success = 'yes';
            $message = 'Buy credit Successfully';
        } catch (Exception $e) {
            /*
             * if something went wrong
             */
            $message = $e->getMessage();
        }
        if ($success == 'yes') {
            $user_info = UserInfo::where('user_id', $user->id)->first();
            $updated_user_info = $user_info->update([
                'balance' => $user_info->balance + $request->price,
            ]);
        }
        return response()->json([
            'message' => $message,
            'success' => $success
        ]);
    }
}
