<?php

use App\Http\Controllers\Admin\ChatController;
use App\Http\Controllers\Admin\PerMinutePackageController;
use App\Http\Controllers\Admin\ReviewController;
use App\Http\Controllers\Admin\SettingController;
use App\Http\Controllers\Frontend\CustomerController;
use App\Http\Controllers\Frontend\FrontendPsychicCategoryController;
use App\Http\Controllers\Frontend\HomeController;
use App\Http\Controllers\Frontend\SinglePsychicController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\Admin\UserController;
use App\Http\Controllers\Admin\PsychicController;
use App\Http\Controllers\Admin\PsychicCategoryController;
use App\Http\Controllers\Admin\PackageController;
use App\Http\Controllers\Auth\RegisteredUserController;
use Illuminate\Support\Facades\Route;

Route::post('/psychic/direct-login', [RegisteredUserController::class, 'direct_login'])->middleware(['auth', 'verified'])->name('psychic.direct-login');
Route::get('/', [HomeController::class, 'index'])->name('home');
Route::get('/my-activity', [CustomerController::class, 'my_activity'])->middleware(['auth', 'verified'])->name('user.my-activity');
Route::get('/favorite-advisors', [CustomerController::class, 'favorite_advisors'])->middleware(['auth', 'verified'])->name('user.favorite-advisors');
Route::get('/my-activity/{name}', [CustomerController::class, 'my_activity_single'])->middleware(['auth', 'verified'])->name('user.my-activity.single');
Route::get('/psychics/category/{psychic_category}', [FrontendPsychicCategoryController::class, 'index'])->name('psychics.category');
Route::get('/psychics', [FrontendPsychicCategoryController::class, 'all_advisors'])->name('psychics.all');
Route::get('/psychics/{name}', [SinglePsychicController::class, 'index'])->name('psychic.single');
Route::get('/privacy-policy', function () {
    $class_name = 'single-psychic';
    return view('frontend.privacy-policy', compact('class_name'));
})->name('privacy-policy');
Route::get('/terms-of-use', function () {
    $class_name = 'single-psychic';
    return view('frontend.terms-of-use', compact('class_name'));
})->name('terms-of-use');
Route::get('/psychic-terms-of-use', function () {
    $class_name = 'single-psychic';
    return view('frontend.psychic-terms-of-use', compact('class_name'));
})->name('psychic-terms-of-use');
Route::get('/data-deletation', function () {
    $class_name = 'single-psychic';
    return view('frontend.data-deletation', compact('class_name'));
})->name('data-deletation');
Route::post('/payment', [SinglePsychicController::class, 'payment']);
Route::post('/fav-psychic', [SinglePsychicController::class, 'fav_psychic']);
Route::post('/rating', [SinglePsychicController::class, 'rating']);
Route::post('/review/show-more', [SinglePsychicController::class, 'more_review']);
Route::get('/psychics/{name}/voice-call', [SinglePsychicController::class, 'voice_call'])->middleware(['auth', 'verified'])->name('psychic.voice-call');
Route::get('/psychic-chat', [ChatController::class, 'psychic_index'])->middleware(['auth', 'verified'])->name('psychic.chat');
// Route::post('/psychics/chat', [SinglePsychicController::class, 'chat'])->middleware(['auth', 'verified']);
Route::get('/psychics/{name}/chat', [SinglePsychicController::class, 'chat'])->middleware(['auth', 'verified'])->name('psychics.chat');
Route::post('/psychic/send-message', [SinglePsychicController::class, 'send_message']);
Route::post('/psychic/end-chat', [SinglePsychicController::class, 'end_chat']);
Route::post('/psychic/current-chatdate', [SinglePsychicController::class, 'current_chatdate']);
Route::get('/twilio-request', [SinglePsychicController::class, 'twilio_request'])->name('twilio-request');
Route::get('/twilio-token', [SinglePsychicController::class, 'twilio_token'])->name('twilio-token');
Route::post('/psychic-voice-call', [SinglePsychicController::class, 'psychic_voice_call']);

Route::get('/dashboard', [HomeController::class, 'dashboard'])->middleware(['auth', 'verified'])->name('dashboard');

Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
});

Route::get('/clear-cache', function () {
    Artisan::call('cache:clear');
    Artisan::call('config:clear');
    Artisan::call('config:cache');
    Artisan::call('view:clear');

    return redirect()->back()->with('success', 'cleared!');
});
Route::resource('/user', UserController::class)->middleware(['auth', 'verified']);
Route::resource('/chat', ChatController::class)->middleware(['auth', 'verified']);
Route::get('/user/{id}/booking', [UserController::class, 'user_booking'])->middleware(['auth', 'verified'])->name('user.booking');
Route::post('/user/edit-profile', [UserController::class, 'edit_profile'])->middleware(['auth', 'verified'])->name('user.edit-profile');
Route::resource('/psychic', PsychicController::class)->middleware(['auth', 'verified']);
Route::post('/psychic/edit-profile', [PsychicController::class, 'edit_profile'])->middleware(['auth', 'verified'])->name('psychic.edit-profile');
Route::post('/psychic-category-choose', [PsychicController::class, 'psychic_category_choose'])->middleware(['auth', 'verified'])->name('psychic-category-choose');
Route::get('/psychic/{id}/booking', [PsychicController::class, 'psychic_booking'])->middleware(['auth', 'verified'])->name('psychic.booking');
Route::post('/psychic/twilio-validation-code', [PsychicController::class, 'twilio_validation_code']);
Route::post('/psychic/verify-phone', [PsychicController::class, 'verify_phone']);
Route::resource('/psychic-category', PsychicCategoryController::class)->middleware(['auth', 'verified']);
Route::resource('/package', PackageController::class)->middleware(['auth', 'verified']);
Route::resource('/per-minute-package', PerMinutePackageController::class)->middleware(['auth', 'verified']);
Route::resource('/review', ReviewController::class)->middleware(['auth', 'verified']);
Route::resource('/setting', SettingController::class)->middleware(['auth', 'verified']);
require __DIR__ . '/auth.php';